WeRoBot
=======


WeRoBot 是一个微信机器人框架，采用 MIT 协议发布。

如果你在使用 WeRoBot 的过程中有什么建议或者疑惑，欢迎去 https://github.com/whtsky/WeRoBot/issues 提 Issue 或者给我发邮件： whtsky [at] gmail.com

.. toctree::
    :maxdepth: 2

    start
    handlers
    messages
    replies
    session
    client
    pay
    deploy
    utils
    changelog
